import React, { useState, useEffect, useRef, Fragment } from "react";
import { Row, Col, Space } from 'antd';
import TableView from '@/components/TableView';

export default function KeyVisits(props) {
  const tagList = [{ label: '精神障碍', color: '#C64FBE' }, { label: '吸毒', color: '#D8A247' }, { label: '社区矫正', color: '#B82F6E' }, { label: '刑满释放', color: '#199C8F' }, { label: '流浪', color: '#3ECB7A' }, { label: '重点青少年', color: '#117AC1' }, { label: '涉稳涉访', color: '#6865D7' }, { label: '潜在风险', color: '#2661CE' }]
  const visitMap = {
    visitTotal: 12,
    channelList: [
      {
        name: '综治中心',
        number: 3
      },
      {
        name: '信访',
        number: 4
      },
      {
        name: '网格',
        number: 2
      },
      {
        name: '12345热线',
        number: 3
      },
    ],
    identityList: [
      {
        name: '申请方当事人',
        number: 3
      },
      {
        name: '被申请方代理人',
        number: 1
      },
      {
        name: '被申请方代理人',
        number: 2
      },
      {
        name: '被申请方代理人',
        number: 1
      },
    ]
  }

  const fakeData1 = [
    {
      id: 1,
      caseNo: 'A20230101',
      judicNo: 'J20230101',
      perClassName: '自然人',
      inputUserName: '张三',
      mediateUserName: '李四',
      judgeName: '王五',
      mediator: '赵六',
      handlerUserName: '钱七',
      returnUserName: '孙八',
      expireTime: '2023-08-10T08:00:00.000Z',
      processName: '进行中',
      otherMediator: '周九',
      canalName: '网络',
      judicResult: '通过',
      assistName: '吴十',
      mediTypeName: '民事调解',
      serieStatus: '1', // 1 表示非系列案，2 表示系列案
      // 更多字段...
    },
    // 更多数据...
  ];

  // 列配置
  const fakeColumns = [
    {
      title: '时间',
      dataIndex: 'expireTime',
      key: 'expireTime',
      defaultSortOrder: 'descend',
      width: 180,
      sorter: (a, b) => a.age - b.age,
    },
    {
      title: '数据来源',
      dataIndex: 'judicNo',
      key: 'judicNo',
    },
    {
      title: '事项状态',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '化解结果',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '事件类型',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '问题属地',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '事项来源',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '事项等级',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '申请方',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '被申请方',
      dataIndex: 'perClassName',
      key: 'perClassName',
    },
    {
      title: '操作',
      dataIndex: 'perClassName',
      key: 'perClassName',
      width: 120,
      fixed: 'right',
      render: (text) => (
        <div style={{ display: 'flex', color: '#1A6FB8', gap: '16px' }}>
          <div>详情</div>
        </div>
      )
    },
  ];
  return (
    <div>
      <Col span={24} style={{ display: 'flex', alignItems: 'center', marginBottom: '16px' }}>
        <Space size='small'>
          <div className='MediationInfo-subTitle' ></div><span style={{ fontWeight: '600' }}>重点人员标签</span>
        </Space>
      </Col>
      <Space style={{ marginBottom: '20px' }}>
        {tagList?.map((item, index) => (
          <div key={index} className="dialogTag" style={{ backgroundColor: item.color }}>{item.label}</div>
        ))}
      </Space>
      <Col span={24} style={{ display: 'flex', alignItems: 'center', marginBottom: '16px' }}>
        <Space size='small'>
          <div className='MediationInfo-subTitle' ></div><span style={{ fontWeight: '600' }}>反映诉求记录</span>
        </Space>
      </Col>
      <div style={{marginBottom: '16px'}}>
        <div><span>来访总数： </span><span style={{ color: '#1a6fb8' }}>{visitMap.visitTotal}</span> 次</div>
        <div><span>来访渠道： </span>{visitMap.channelList.map((item, index) => {
          return <span>{index !== 0 && '、'}{item.name}<span style={{ color: '#1a6fb8' }}>{item.number}</span>次</span>
        })}</div>
        <div><span>来访身份：</span>{visitMap.identityList.map((item, index) => {
          return <span>{index !== 0 && '、'}{item.name}：<span style={{ color: '#1a6fb8' }}>{item.number}</span>次</span>
        })}</div>
      </div>
      <TableView
        columns={fakeColumns}
        dataSource={fakeData1}
        size="small"
        rowKey="id"
        bordered={true}
        style={{ marginBottom: '60px' }}
        className='visitTableClass'
        scroll={{ x: 1300 }}
      />
    </div>
  )
}
